@@ -10,7 +10,8 @@ class TextareaWysiwyg(Textarea):
 
     def __init__(self, attrs=None, extraskwargs=True):
         if extraskwargs:
-            attrs = update_kwargs(attrs, self.__class__.__name__, base_class='wysiwyg form-control')
-        attrs['data-option-image']=reverse_lazy('upload_image')
 
+            attrs = update_kwargs(attrs, self.__class__.__name__, base_class='wysiwyg form-control')
+        attrs['data-option-image']=reverse_lazy('tinymce_upload_image')
+        attrs['data-option-video']=reverse_lazy('tinymce_upload_video')
         super().__init__(attrs)
